==> tiltfive_sdk_1.3.3.tar.xz: tiltfive_sdk_1.3.3/Native/docs/html/hierarchy.js <==
var hierarchy =
[
    [ "std::enable_shared_from_this< Client >", "http://gcc.gnu.org/onlinedocs/libstdc++/latest-doxygen/a06689.html", [
      [ "tiltfive::Client", "a03636.html", null ]
    ] ],
    [ "std::enable_shared_from_this< Glasses >", "http://gcc.gnu.org/onlinedocs/libstdc++/latest-doxygen/a06689.html", [
      [ "tiltfive::Glasses", "a03640.html", null ]
    ] ],
    [ "std::enable_shared_from_this< WandStreamHelper >", "http://gcc.gnu.org/onlinedocs/libstdc++/latest-doxygen/a06689.html", [
      [ "tiltfive::WandStreamHelper", "a03648.html", null ]
    ] ],
    [ "std::error_category", null, [
      [ "tiltfive::details::ErrorCategory< Dummy >", "a03592.html", null ]
    ] ],
    [ "std::exception", "http://gcc.gnu.org/onlinedocs/libstdc++/latest-doxygen/a05405.html", [
      [ "std::logic_error", "http://gcc.gnu.org/onlinedocs/libstdc++/latest-doxygen/a02945.html", [
        [ "tiltfive::BadResultAccess", "a03600.html", null ]
      ] ]
    ] ],
    [ "tiltfive::GlassesConnectionHelper", "a03644.html", null ],
    [ "std::integral_constant< class, __v >", "http://gcc.gnu.org/onlinedocs/libstdc++/latest-doxygen/a03229.html", [
      [ "std::is_error_code_enum< tiltfive::Error >", "a03596.html", null ],
      [ "tiltfive::supports_ostream< T, Enable >", "a03624.html", null ],
      [ "tiltfive::supports_ostream< T, decltype(std::declval< std::ostream & >()<< std::declval< T >())>", "a03628.html", null ]
    ] ],
    [ "tiltfive::ParamChangeHelper", "a03656.html", null ],
    [ "tiltfive::ParamChangeListener", "a03652.html", null ],
    [ "tiltfive::Result< T >", "a03604.html", null ],
    [ "tiltfive::Result< void >", "a03616.html", null ],
    [ "T5_CameraStreamConfig", "a03688.html", null ],
    [ "T5_CamImage", "a03700.html", null ],
    [ "T5_ClientInfo", "a03680.html", null ],
    [ "T5_FrameInfo", "a03692.html", null ],
    [ "T5_GameboardSize", "a03676.html", null ],
    [ "T5_GlassesPose", "a03684.html", null ],
    [ "T5_Quat", "a03672.html", null ],
    [ "T5_Vec2", "a03664.html", null ],
    [ "T5_Vec3", "a03668.html", null ],
    [ "T5_WandReport", "a03708.html", null ],
    [ "T5_WandStreamConfig", "a03704.html", null ],
    [ "T5_WandStreamEvent", "a03716.html", null ],
    [ "tiltfive::Wand", "a03660.html", null ]
];

==> tiltfive_sdk_1.4.0.tar.xz: tiltfive_sdk_1.4.0/Native/docs/html/hierarchy.js <==
var hierarchy =
[
    [ "std::enable_shared_from_this< Client >", "http://gcc.gnu.org/onlinedocs/libstdc++/latest-doxygen/a06689.html", [
      [ "tiltfive::Client", "a03636.html", null ]
    ] ],
    [ "std::enable_shared_from_this< Glasses >", "http://gcc.gnu.org/onlinedocs/libstdc++/latest-doxygen/a06689.html", [
      [ "tiltfive::Glasses", "a03640.html", null ]
    ] ],
    [ "std::enable_shared_from_this< WandStreamHelper >", "http://gcc.gnu.org/onlinedocs/libstdc++/latest-doxygen/a06689.html", [
      [ "tiltfive::WandStreamHelper", "a03648.html", null ]
    ] ],
    [ "std::error_category", null, [
      [ "tiltfive::details::ErrorCategory< Dummy >", "a03592.html", null ]
    ] ],
    [ "std::exception", "http://gcc.gnu.org/onlinedocs/libstdc++/latest-doxygen/a05405.html", [
      [ "std::logic_error", "http://gcc.gnu.org/onlinedocs/libstdc++/latest-doxygen/a02945.html", [
        [ "tiltfive::BadResultAccess", "a03600.html", null ]
      ] ]
    ] ],
    [ "tiltfive::GlassesConnectionHelper", "a03644.html", null ],
    [ "std::integral_constant< class, __v >", "http://gcc.gnu.org/onlinedocs/libstdc++/latest-doxygen/a03229.html", [
      [ "std::is_error_code_enum< tiltfive::Error >", "a03596.html", null ],
      [ "tiltfive::supports_ostream< T, Enable >", "a03624.html", null ],
      [ "tiltfive::supports_ostream< T, decltype(std::declval< std::ostream & >()<< std::declval< T >())>", "a03628.html", null ]
    ] ],
    [ "tiltfive::ParamChangeHelper", "a03656.html", null ],
    [ "tiltfive::ParamChangeListener", "a03652.html", null ],
    [ "tiltfive::Result< T >", "a03604.html", null ],
    [ "tiltfive::Result< void >", "a03616.html", null ],
    [ "T5_CameraStreamConfig", "a03696.html", null ],
    [ "T5_CamImage", "a03708.html", null ],
    [ "T5_ClientInfo", "a03688.html", null ],
    [ "T5_FrameInfo", "a03700.html", null ],
    [ "T5_GameboardSize", "a03684.html", null ],
    [ "T5_GlassesPose", "a03692.html", null ],
    [ "T5_GraphicsContextGL", "a03676.html", null ],
    [ "T5_GraphicsContextVulkan", "a03680.html", null ],
    [ "T5_ProjectionInfo", "a03728.html", null ],
    [ "T5_Quat", "a03672.html", null ],
    [ "T5_Vec2", "a03664.html", null ],
    [ "T5_Vec3", "a03668.html", null ],
    [ "T5_WandReport", "a03716.html", null ],
    [ "T5_WandStreamConfig", "a03712.html", null ],
    [ "T5_WandStreamEvent", "a03724.html", null ],
    [ "tiltfive::Wand", "a03660.html", null ]
];
